@@ -1,6 +1,6 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	@(#) mhinit.pl 2.17 99/08/15 21:20:28
+##	@(#) mhinit.pl 2.20 00/02/13 03:28:47
 ##  Author:
 ##      Earl Hood       mhonarc@pobox.com
 ##  Description:
@@ -242,6 +242,7 @@ $DBPathName	= '';	# Full pathname of database file
     "application/octet-stream",		"m2h_external::filter",
     "application/x-patch",		"m2h_text_plain::filter",
     "message/delivery-status",  	"m2h_text_plain::filter",
+    "message/external-body",   		"m2h_msg_extbody::filter",
     "message/partial",   		"m2h_text_plain::filter",
     "text/enriched",    		"m2h_text_enriched::filter",
     "text/html",			"m2h_text_html::filter",
@@ -267,6 +268,8 @@ $DBPathName	= '';	# Full pathname of database file
     #-------------------------------------------------------------------
     "application/octet-stream",		"mhexternal.pl",
     "application/x-patch",		"mhtxtplain.pl",
+    "message/delivery-status",  	"mhtxtplain.pl",
+    "message/external-body",   		"mhmsgextbody.pl",
     "message/partial",   		"mhtxtplain.pl",
     "text/enriched",    		"mhtxtenrich.pl",
     "text/html",			"mhtxthtml.pl",
@@ -358,7 +361,7 @@ $DBPathName	= '';	# Full pathname of database file
 $MHeadCnvFunc	= "mhonarc::htmlize";
 
 ##  Regexp for variable detection
-$VarExp = '\$([^\$]*)\$';
+$VarExp    = $ENV{'M2H_VARREGEX'}   || '\$([^\$]*)\$';
 
 ##  Regexp for address/msg-id detection (looks like cussing in cartoons)
 $AddrExp = q%[^()<>@,;:\/\s"'&|]+@[^()<>@,;:\/\s"'&|]+%;
@@ -385,7 +388,8 @@ $TITLE     = $ENV{'M2H_TITLE'}      || "Mail Index";
 $MAILTOURL = $ENV{'M2H_MAILTOURL'}  || "";
 $FROM      = $ENV{'M2H_MSGSEP'}     || '^From ';
 $LOCKFILE  = $ENV{'M2H_LOCKFILE'}   ||
-	     (($MSDOS || $VMS) ? "mhonarc.lck": ".mhonarc.lck");
+	     ($MSDOS ? "mhonarc.lck" :
+		$VMS ? "mhonarc_lck" : ".mhonarc.lck");
 $LOCKTRIES = $ENV{'M2H_LOCKTRIES'}  || 10;
 $LOCKDELAY = $ENV{'M2H_LOCKDELAY'}  || 3;
 $MAXSIZE   = $ENV{'M2H_MAXSIZE'}    || 0;
