@@ -1,6 +1,6 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	@(#) mhrcvars.pl 2.8 99/08/08 20:01:37
+##	@(#) mhrcvars.pl 2.11 00/01/19 13:16:41
 ##  Author:
 ##      Earl Hood       mhonarc@pobox.com
 ##  Description:
@@ -415,6 +415,34 @@ sub replace_li_var {
 	    }
 	    last REPLACESW;
 	}
+	if ($var eq 'PGLINKLIST') {
+	    my $num = $PageNum;
+	    my $t = $arg =~ s/T//i;
+	    my($before, $after) = split(/;/, $arg);
+	    my $prefix  = $t ? $TIDXPREFIX : $IDXPREFIX;
+	    my $suffix  = $HtmlExt;
+	       $suffix .= '.gz'  if $GzipLinks;
+	    $before = $num - abs($before);
+	    $after  = $num + abs($after);
+	    $tmp = "";
+	    for ($i=$before; $i < $num; ++$i) {
+		next  if $i < 1;
+		if ($i < 2) {
+		    $tmp .= sprintf('<A HREF="%s%s">%d</A> | ',
+				    ($t ? $TIDXNAME : $IDXNAME),
+				    ($GzipLinks ? '.gz' : ""), $i);
+		    next;
+		}
+		$tmp .= sprintf('<A HREF="%s%d.%s">%d</A> | ',
+			        $prefix, $i, $suffix, $i);
+	    }
+	    $tmp .= $num;
+	    for ($i=$num+1; $i <= $after && $i <= $NumOfPages; ++$i) {
+		$tmp .= sprintf(' | <A HREF="%s%d.%s">%d</A>',
+			        $prefix, $i, $suffix, $i);
+	    }
+	    last REPLACESW;
+	}
 
 	if ($var eq 'PAGENUM') {
 	    $tmp = $PageNum;
@@ -514,7 +542,7 @@ sub replace_li_var {
 
     ##	Check if string needs to be expanded again
     if ($expand) {
-	$tmp =~ s/\$([^\$]*)\$/&replace_li_var($1,$index)/ge;
+	$tmp =~ s/$VarExp/&replace_li_var($1,$index)/geo;
     }
 
     ##	Check if URL text specifier is set
